Execute derive functions via embedded QuickJS runtime.
Each derive entry declares sources (loader keys) and fn (JS function source).
This module evaluates the function with the corresponding loader data as arguments
and returns all derive results as a JSON object.
Functions
- execute_
derives - Execute all derive definitions against loader data, returning a JSON object with derive results keyed by derive name.